@@ -37,6 +37,8 @@ class RequestConfig:
         Arguments:
             table (`~.Table`): table to be configured
         """
+        table.request = self.request
+
         order_by = self.request.GET.getlist(table.prefixed_order_by_field)
         if order_by:
             table.order_by = order_by
@@ -47,7 +49,7 @@ class RequestConfig:
                 kwargs = {}
             # extract some options from the request
             for arg in ("page", "per_page"):
-                name = getattr(table, "prefixed_%s_field" % arg)
+                name = getattr(table, f"prefixed_{arg}_field")
                 try:
                     kwargs[arg] = int(self.request.GET[name])
                 except (ValueError, KeyError):
@@ -64,6 +66,4 @@ class RequestConfig:
                 except EmptyPage:
                     table.page = table.paginator.page(table.paginator.num_pages)
 
-        table.request = self.request
-
         return table
