@@ -72,9 +72,9 @@ class OrderBy(str):
         instance = super().__new__(cls, value)
         if Accessor.LEGACY_SEPARATOR in value:
             message = (
-                "Use '__' to separate path components, not '.' in accessor '{}'"
+                f"Use '__' to separate path components, not '.' in accessor '{value}'"
                 " (fallback will be removed in django_tables2 version 3)."
-            ).format(value)
+            )
 
             warnings.warn(message, DeprecationWarning, stacklevel=3)
 
@@ -281,7 +281,7 @@ class OrderByTuple(tuple):
             >>> order_by.opposite
             ('-name', 'age')
         """
-        return type(self)((o.opposite for o in self))
+        return type(self)(o.opposite for o in self)
 
 
 class Accessor(str):
@@ -303,15 +303,20 @@ class Accessor(str):
         "Failed lookup for key [{key}] in {context}, when resolving the accessor {accessor}"
     )
 
-    def __new__(cls, value):
+    def __init__(self, value, callable_args=None, callable_kwargs=None):
+        self.callable_args = callable_args or getattr(value, "callable_args", None) or []
+        self.callable_kwargs = callable_kwargs or getattr(value, "callable_kwargs", None) or {}
+        super().__init__()
+
+    def __new__(cls, value, callable_args=None, callable_kwargs=None):
         instance = super().__new__(cls, value)
         if cls.LEGACY_SEPARATOR in value:
             instance.SEPARATOR = cls.LEGACY_SEPARATOR
 
             message = (
-                "Use '__' to separate path components, not '.' in accessor '{}'"
+                f"Use '__' to separate path components, not '.' in accessor '{value}'"
                 " (fallback will be removed in django_tables2 version 3)."
-            ).format(value)
+            )
 
             warnings.warn(message, DeprecationWarning, stacklevel=3)
 
@@ -392,9 +397,9 @@ class Accessor(str):
                             )
                 if callable(current):
                     if safe and getattr(current, "alters_data", False):
-                        raise ValueError(self.ALTERS_DATA_ERROR_FMT.format(method=repr(current)))
+                        raise ValueError(self.ALTERS_DATA_ERROR_FMT.format(method=current.__name__))
                     if not getattr(current, "do_not_call_in_templates", False):
-                        current = current()
+                        current = current(*self.callable_args, **self.callable_kwargs)
                 # Important that we break in None case, or a relationship
                 # spanning across a null-key will raise an exception in the
                 # next iteration, instead of defaulting.
