@@ -153,7 +153,7 @@ class ExportViewTest(TestCase):
     def test_should_raise_error_for_unsupported_file_type(self):
         table = Table([])
 
-        with self.assertRaises(TypeError):
+        with self.assertRaisesMessage(TypeError, 'Export format "exe" is not supported.'):
             TableExport(table=table, export_format="exe")
 
     def test_should_support_json_export(self):
@@ -194,7 +194,7 @@ class ExportViewTest(TestCase):
             export_format = request.GET.get("_export", None)
             if TableExport.is_valid_format(export_format):
                 exporter = TableExport(export_format, table)
-                return exporter.response("table.{}".format(export_format))
+                return exporter.response(f"table.{export_format}")
 
             return render(request, "django_tables2/table.html", {"table": table})
 
@@ -259,9 +259,9 @@ class AdvancedExportViewTest(TestCase):
         response = OccupationView.as_view()(build_request("/?_export=xls"))
         data = response.content
         # binary data, so not possible to compare to an exact expectation
-        self.assertTrue(data.find("Vlaanderen".encode()))
-        self.assertTrue(data.find("Ecoloog".encode()))
-        self.assertTrue(data.find("Timmerman".encode()))
+        self.assertTrue(data.find(b"Vlaanderen"))
+        self.assertTrue(data.find(b"Ecoloog"))
+        self.assertTrue(data.find(b"Timmerman"))
 
     def test_datetime_xls(self):
         """Verify datatime objects can be exported to xls."""
@@ -294,7 +294,7 @@ class AdvancedExportViewTest(TestCase):
         self.assertEqual(data, expected_csv)
 
         response = View.as_view()(build_request("/?_export=xls"))
-        self.assertIn("07/22/2019 1:11 p.m.".encode(), response.content)
+        self.assertIn(b"07/22/2019 1:11 p.m.", response.content)
 
     def test_export_invisible_columns(self):
         """Verify columns with visible=False *do* get exported."""
@@ -369,7 +369,7 @@ class UnicodeExportViewTest(TestCase):
         unicode_name = "木匠"
         Occupation.objects.create(name=unicode_name)
 
-        expected_csv = "Name,Boolean,Region\r\n{},,\r\n".format(unicode_name)
+        expected_csv = f"Name,Boolean,Region\r\n{unicode_name},,\r\n"
 
         response = OccupationView.as_view()(build_request("/?_export=csv"))
         self.assertEqual(response.getvalue().decode("utf8"), expected_csv)
